require 'spec_helper'

describe Masheri::RestClient do
  let(:service_key) do
    "12345"
  end

  let(:url) do
    Masheri::RestClient::Query.new(query_params).url
  end

  let(:query_params) do
    {service_id: service_key}.merge(options)
  end


  context "reasonable date range" do
    let(:options) do
      {
        start_date: 1.day.ago,
        end_date:   0.days.ago,
        resource:   "developer_activity"
      }
    end

    it "should request the service data, given a service key" do
      ::RestClient.should_receive(:get).with(url).and_return("whatever")
      Masheri.activity("developer_activity", service_key, options).should == "whatever"
    end
  end

  context "invalid date range" do
    let(:options) do
      {
        start_date: 8.day.ago,
        end_date:   0.days.ago,
        resource:   "developer_activity"
      }
    end

    it "should raise an InvalidDateRange error" do
      expect do
        Masheri.activity("developer_activity", service_key, options)
      end.to raise_error(Masheri::InvalidDateRange)
    end
  end
end
