require 'bundler'
require 'simplecov'

SimpleCov.start

$LOAD_PATH.unshift File.expand_path("./lib")
require 'masheri'

Bundler.require(:test)

RSpec.configure do |config|
  config.treat_symbols_as_metadata_keys_with_true_values = true
  config.run_all_when_everything_filtered = true
  config.filter_run :focus

  # Run specs in random order to surface order dependencies. If you find an
  # order dependency and want to debug it, you can fix the order by providing
  # the seed, which is printed after each run.
  #     --seed 1234
  config.order = 'random'

  config.before do
    Timecop.freeze Time.now
  end

  config.before do
    config = double("config")

    key       = "regular_key"
    secret    = "super_long_secret"
    signature = Digest::MD5.hexdigest(key + secret + Time.now.to_f.to_i.to_s)

    config.stub({
      site_id:   "987",
      key:       key,
      secret:    secret,
      signature: signature,
      host:      "masheri.example.com",
    })

    Masheri.config = config
  end

  config.after do
    Timecop.return
  end
end


